######################
InputStoryContentPhoto
######################


.. automodule:: litegram.types.input_story_content_photo
    :members:
    :member-order: bysource
    :undoc-members: True
    :exclude-members: model_config,model_fields
